pub struct SimpleRedactor { /* private fields */ }Expand description
A redactor that performs a variety of simple transformations on the input text.
Implementations
Sourceimpl SimpleRedactor
impl SimpleRedactor
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with the default mode of SimpleRedactorMode::Replace('*').
Sourcepub const fn with_mode(mode: SimpleRedactorMode) -> Self
pub const fn with_mode(mode: SimpleRedactorMode) -> Self
Creates a new instance with an explicit mode of operation.
Sourcepub const fn mode(&self) -> &SimpleRedactorMode
pub const fn mode(&self) -> &SimpleRedactorMode
Returns the current mode of operation.