pub struct DataClass { /* private fields */ }Expand description
The identity of a well-known data class.
Each data class has a name, which is unique in the context of a specific named taxonomy.
Serialization
Serializing a DataClass produces a string in the format taxonomy/name.
Implementations
Sourceimpl DataClass
impl DataClass
Sourcepub const fn new(taxonomy: &'static str, name: &'static str) -> Self
pub const fn new(taxonomy: &'static str, name: &'static str) -> Self
Creates a new data class instance.
Panics
Panics if taxonomy or name are not valid identifiers. Valid identifiers must
start with _ or an ASCII letter, followed by zero or more _, ASCII letters, or ASCII
digits (e.g., foo, _bar, Baz123)